Struct shiplift::container::ContainerOptions [−][src]
Interface for building a new docker container from an existing image
Fields
name: Option<String>Implementations
impl ContainerOptions[src]
impl ContainerOptions[src]pub fn builder(name: &str) -> ContainerOptionsBuilder[src]
return a new instance of a builder for options
pub fn serialize(&self) -> Result<String>[src]
serialize options as a string. returns None if no options are defined
pub fn parse_from<'a, K, V>(&self, params: &'a HashMap<K, V>, body: &mut Value) where
&'a HashMap<K, V>: IntoIterator,
K: ToString + Eq + Hash,
V: Serialize, [src]
&'a HashMap<K, V>: IntoIterator,
K: ToString + Eq + Hash,
V: Serialize,